@@ -5,8 +5,8 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/cairo -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/libpng16 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include',
-          'libs' => '-lcairo-gobject -lcairo -lgobject-2.0 -lglib-2.0',
+          'inc' => '-I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/lib/libffi-3.2.1/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/harfbuzz -I/usr/include/uuid ',
+          'libs' => '-lcairo-gobject -lcairo -lgobject-2.0 -lglib-2.0 ',
           'typemaps' => []
         };
 
